@@ -131,6 +131,90 @@ class RumClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeLogList(self, request):
+        """获取项目下的日志列表（实例创建的项目下的日志列表）
+
+        :param request: Request instance for DescribeLogList.
+        :type request: :class:`tencentcloud.rum.v20210622.models.DescribeLogListRequest`
+        :rtype: :class:`tencentcloud.rum.v20210622.models.DescribeLogListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeLogList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeLogListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeProjects(self, request):
+        """获取项目列表（实例创建的团队下的项目列表）
+
+        :param request: Request instance for DescribeProjects.
+        :type request: :class:`tencentcloud.rum.v20210622.models.DescribeProjectsRequest`
+        :rtype: :class:`tencentcloud.rum.v20210622.models.DescribeProjectsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeProjects", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeProjectsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeScores(self, request):
+        """获取首页分数列表
+
+        :param request: Request instance for DescribeScores.
+        :type request: :class:`tencentcloud.rum.v20210622.models.DescribeScoresRequest`
+        :rtype: :class:`tencentcloud.rum.v20210622.models.DescribeScoresResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeScores", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeScoresResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
